@@ -4,6 +4,7 @@
 import json
 import uuid
 from collections import Sequence
+import warnings
 
 from neo4jrestclient.constants import RAW
 from neo4jrestclient.request import Request
@@ -32,7 +33,7 @@ class BaseQ(object):
               "eq", "equals", "neq", "notequals")
 
     def __init__(self, property=None, lookup=None, match=None,
-                 nullable=True, var=u"n", **kwargs):
+                 nullable=None, var=u"n", **kwargs):
         self._and = None
         self._or = None
         self._not = None
@@ -41,7 +42,7 @@ class BaseQ(object):
         self.match = match
         self.nullable = nullable
         self.var = var
-        if property and (not self.lookup or not self.match):
+        if property and (not self.lookup or self.match is None):
             for m in self.matchs:
                 if m in kwargs:
                     self.lookup = m
@@ -53,7 +54,7 @@ class BaseQ(object):
                                  " (%s) and a match case".format(all_matchs))
 
     def is_valid(self):
-        return ((self.property and self.lookup and self.match) or
+        return ((self.property and self.lookup and self.match is not None) or
                 (self._and or self._or or self._not))
 
     def _make_and(q1, q2):
@@ -165,10 +166,10 @@ class Q(BaseQ):
             match = matchs
         elif self.lookup == "isnull":
             if self.match:
-                lookup = u"="
+                lookup = u"is"
             else:
-                lookup = u"<>"
-            match = u"null"
+                lookup = u"is not"
+            match = u"NULL"
         elif self.lookup in ["eq", "equals"]:
             lookup = u"="
             if isinstance(self.match, string_types):
@@ -238,26 +239,38 @@ class Q(BaseQ):
             key = u"{0}p{1}".format(prefix, len(params))
             prop = text_type(self.property).replace(u"`", u"\\`")
             NEO4J_V2 = version and version.split(".")[0] >= "2"
-            if NEO4J_V2 and self.nullable is True:
-                try:
-                    query_format = (u"(has({0}.`{1}`) and {2}.`{3}` "
-                                    u"{4} {{{5}}})")
-                    query = query_format.format(self.var, prop,
-                                                self.var, prop,
-                                                lookup, key)
-                except AttributeError:
-                    query = (u"( has(%s.`%s`) and %s.`%s` %s {%s} )"
-                             % (self.var, prop, self.var, prop, lookup, key))
-            if NEO4J_V2 and self.nullable is False:
-                try:
-                    query_format = (u"(not(has({0}.`{1}`)) or {2}.`{3}` "
-                                    u"{4} {{{5}}})")
-                    query = query_format.format(self.var, prop,
-                                                self.var, prop,
-                                                lookup, key)
-                except AttributeError:
-                    query = (u"( not(has(%s.`%s`)) or %s.`%s` %s {%s} )"
-                             % (self.var, prop, self.var, prop, lookup, key))
+            if not NEO4J_V2 and self.nullable is None:
+                # Backwards compatibility for Neo5j versions prior 2.0
+                self.nullable = True
+            if self.lookup == 'isnull':
+                query_format = ("{0}.`{1}` {2} NULL")
+                query = query_format.format(self.var, prop, lookup)
+            elif NEO4J_V2 and self.nullable is not None:
+                warnings.warn("Deprecated, Neo4j +2.0.0 does not support "
+                              "the use of 'nullable' ('!' and '?' operators).",
+                              DeprecationWarning)
+                if self.nullable is True:
+                    try:
+                        query_format = (u"(has({0}.`{1}`) and {2}.`{3}` "
+                                        u"{4} {{{5}}})")
+                        query = query_format.format(self.var, prop,
+                                                    self.var, prop,
+                                                    lookup, key)
+                    except AttributeError:
+                        query = (u"( has(%s.`%s`) and %s.`%s` %s {%s} )"
+                                 % (self.var, prop, self.var, prop, lookup,
+                                    key))
+                elif self.nullable is False:
+                    try:
+                        query_format = (u"(not(has({0}.`{1}`)) or {2}.`{3}` "
+                                        u"{4} {{{5}}})")
+                        query = query_format.format(self.var, prop,
+                                                    self.var, prop,
+                                                    lookup, key)
+                    except AttributeError:
+                        query = (u"( not(has(%s.`%s`)) or %s.`%s` %s {%s} )"
+                                 % (self.var, prop, self.var, prop, lookup,
+                                    key))
             else:
                 if NEO4J_V2:
                     nullable = u""
